==> haskell-hls-stylish-haskell-plugin-2.1.0.0-61-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-stylish-haskell-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-stylish-haskell-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-stylish-haskell-plugin-2.1.0.0-85f2u5CYa9vFb05YVgOghC
key:                  hls-stylish-haskell-plugin-2.1.0.0-85f2u5CYa9vFb05YVgOghC
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
synopsis:             Integration with the Stylish Haskell code formatter
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  4f69c344065b6b8b19d564b10af0f9de
exposed:              True
exposed-modules:      Ide.Plugin.StylishHaskell
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-stylish-haskell-plugin-2.1.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-stylish-haskell-plugin-2.1.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-stylish-haskell-plugin-2.1.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-stylish-haskell-plugin
hs-libraries:         HShls-stylish-haskell-plugin-2.1.0.0-85f2u5CYa9vFb05YVgOghC
depends:
    base-4.17.2.1 directory-1.3.7.1 filepath-1.4.2.2 ghc-9.4.8
    ghc-boot-th-9.4.8 ghcide-2.1.0.0-7mveeBu1NdO3tDaPLTwSr0
    hls-plugin-api-2.1.0.0-2mMBQBjk997A47exxFPkZd
    lsp-types-2.0.1.0-11kcCUIWM0n8rW3sZUJHGA mtl-2.2.2
    stylish-haskell-0.14.4.0-2If8gH2JkLr7S7rRNRkTjV text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hls-stylish-haskell-plugin/html/hls-stylish-haskell-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-stylish-haskell-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-stylish-haskell-plugin-2.1.0.0-96-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-stylish-haskell-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-stylish-haskell-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-stylish-haskell-plugin-2.1.0.0-4Jm7c5FsngED2rg6bqoV2u
key:                  hls-stylish-haskell-plugin-2.1.0.0-4Jm7c5FsngED2rg6bqoV2u
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
synopsis:             Integration with the Stylish Haskell code formatter
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  d682f3b3a8bfc800268740f7e7ebe428
exposed:              True
exposed-modules:      Ide.Plugin.StylishHaskell
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-stylish-haskell-plugin-2.1.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-stylish-haskell-plugin-2.1.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-stylish-haskell-plugin-2.1.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-stylish-haskell-plugin
hs-libraries:         HShls-stylish-haskell-plugin-2.1.0.0-4Jm7c5FsngED2rg6bqoV2u
depends:
    base-4.17.2.1 directory-1.3.7.1 filepath-1.4.2.2 ghc-9.4.8
    ghc-boot-th-9.4.8 ghcide-2.1.0.0-EGobQkKgR8zaeADYgxOC5
    hls-plugin-api-2.1.0.0-EfBvd6pBF3is65S9wzuFu
    lsp-types-2.0.1.0-EjYcMkrIVdu9wybjt2x400 mtl-2.2.2
    stylish-haskell-0.14.4.0-6Z8jMnIDx6TF3f4KHLqD7S text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hls-stylish-haskell-plugin/html/hls-stylish-haskell-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-stylish-haskell-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
